@@ -1,4 +1,4 @@
-/* $Id: fmail.h,v 1.30 2002/01/08 05:22:50 fesnel Exp $ */
+/* $Id: fmail.h,v 1.37 2002/07/30 07:51:27 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -30,15 +30,20 @@
 #ifndef _FMAIL_H
 	#define _FMAIL_H
 
+	using namespace std;
+
 	#ifdef DMALLOC
 			#include <dmalloc.h>
 	#endif
 
+	#ifdef HAVE_LOCALE_H
+		#include <locale.h>
+	#endif
+
 	#include <glib.h>
 
 	#include <gettext.h>
 
-
 	#if defined(__linux__) && defined(__alpha__)
 		#define _linuxalpha_
 	#endif
@@ -47,8 +52,13 @@
 		#include <config.h>
 	#endif
 
-	#include <vector>
+	#include <iostream>
+	#include <fstream>
 	#include <list>
+	#include <map>
+	#include <string>
+	#include <vector>
+
 	#include <stdio.h>
 	#include <stdlib.h>
 
@@ -239,12 +249,12 @@ extern int vsnprintf(char *, size_t, const char *, va_list);
 
 	#define MAX_FIELD_NAME_LEN  32  /* limit of field name length in mail header */
 	#define MAX_FIELDS_IN_HDR   256  /* maximum fields in msg header */
-	#define MAX_FIELD_LEN       988 /* limit on length of field */
+	#define MAX_FIELD_LEN       998 /* limit on length of field */
 	#define MAX_SPLIT_FIELD_LEN 32768   /* limit on length of splitted field */
 	#define MAX_ADDR_IN_FIELD   1024    /* limit on max recipients in field */
 	#define FLD_BREAK       80  /* line length limit in field */
 	#define MAX_FOLD_NAME_LEN   255 /* maximal length of folder name */
-	#define MAX_MH_FOLD_NAME_LEN    16  /* maximal length of folder name (MH) */
+	#define MAX_MH_FOLD_NAME_LEN    64  /* maximal length of folder name (MH) */
 	#define MAX_IMAP_FOLD_NAME_LEN  255 /*maximal length of folder name (IMAP)*/
 	#define STATUS_FIELD        "XFMstatus" /* name of status field in mail header */
 	#define STATUS_FIELD_LEN    9   /* length of stat. field name */
@@ -778,9 +788,6 @@ extern int  mmapfd;     /* mmaped file descriptor */
 /* initialize cache */
 int init_cache();
 
-/* free memory taken by cache structure */
-void discard_cache(struct _mail_folder *folder);
-
 /* close folder's cache */
 void close_cache(struct _mail_folder *folder);
 
@@ -1319,7 +1326,7 @@ int get_month(char *str);
 
 /* returns number of the weekday with name at the beginning of str */
 /* returns -1 if str is not a valid weekday name */
-int get_day(char *str);
+int get_day(const char *str);
 
 /* returns offset of timezone from GMT in seconds */
 /* returns -1 if timezone is not known */
@@ -1332,14 +1339,14 @@ int get_date_offt();
 char *get_arpa_date(time_t t);
 
 /* parses string with date ( mail format ) and returns time in time_t val */
-time_t get_date(char *str);
+time_t get_date(const char *str);
 
 /* return GMT offset of specified date string */
-int parse_offt(char *str);
+int parse_offt(const char *str);
 
 /* parse mail address. returns NULL if error or linked list of addresses */
 /* if ok */
-struct _mail_addr *get_address(char *str, int flags);
+struct _mail_addr *get_address(const char *str, int flags);
 	#define ADDR_IGNORE_COMMAS  0x01    /* treat commas as part of address */
 	#define ADDR_GET_FIRST      0x02    /* parse only first address in list */
 
