@@ -1,4 +1,4 @@
-/* $Id: mbox.cpp,v 1.11 2002/01/05 07:53:11 cfreeze Exp $ */
+/* $Id: mbox.cpp,v 1.13 2002/10/13 21:22:45 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -26,7 +26,6 @@
  ******************************************************************************/
 
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <cfgfile.h>
@@ -595,7 +594,7 @@ struct _mail_msg *get_mbox_message(long uid, struct _mail_folder *folder) {
 	time_t rt;
 	int eoh, flags;
 	size_t clength = 0;
-	off_t shuid = uid;
+	off_t shuid, from_uid;
 
 	if((ffd = get_mbox_folder_fd(folder, READMBOXMODE)) == NULL)
 		return NULL;
@@ -609,11 +608,14 @@ struct _mail_msg *get_mbox_message(long uid, struct _mail_folder *folder) {
 		return NULL;
 	}
 
-	if(!fgets(buf, 255, ffd)) {
-		display_msg(MSG_WARN, "get message", "Error reading message (%ld)",
-					uid);
-		return NULL;
-	}
+	do {
+		from_uid = ftell(ffd);
+		if(!fgets(buf, 255, ffd)) {
+			display_msg(MSG_WARN, "get message", "Error reading message (%ld)",
+				uid);
+			return NULL;
+		}
+	} while (buf[0] == '\0' || buf[0] == '\r' || buf[0] == '\n');
 
 	if((rt = is_from(buf, NULL, 0)) == 0) {
 		display_msg(MSG_WARN, "get message",
@@ -644,7 +646,7 @@ struct _mail_msg *get_mbox_message(long uid, struct _mail_folder *folder) {
 	mbox_message(msg);
 	msg->folder = folder;
 	msg->num = -1;
-	msg->uid = uid;
+	msg->uid = from_uid;
 	msg->real_uid = 1;
 	msg->flags |= hd->flags;
 	msg->header = hd;
@@ -673,7 +675,7 @@ struct _mail_msg *get_mbox_message(long uid, struct _mail_folder *folder) {
 	hf = find_field_noload(msg, MIME_C_LENGTH);
 	if(hf) {
 		clength = (size_t) atoi(hf->f_line);
-		if(clength > (spec->fsize - uid))
+		if(clength > (spec->fsize - from_uid))
 			clength = 0;
 	}
 
