@@ -1,4 +1,4 @@
-/* $Id: pop.cpp,v 1.16 2002/01/05 07:53:11 cfreeze Exp $ */
+/* $Id: pop.cpp,v 1.18 2002/05/18 21:27:49 cfreeze Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -26,13 +26,11 @@
  ******************************************************************************/
 
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <cfgfile.h>
 #include <connection.h>
 #include <connectionManager.h>
-#include <list>
 #include "md5.h"
 
 #ifdef USE_THREADS
@@ -1616,7 +1614,10 @@ void init_pop_source(struct _retrieve_src *source) {
 		while(pop->uidlcache) {
 			ucache = pop->uidlcache;
 			pop->uidlcache = pop->uidlcache->next;
-			free(ucache);
+			if(ucache != NULL) {
+				free(ucache);
+				ucache = NULL;
+			}
 		}
 
 		for(i = 0; i < MAX_POP_UIDS; i++) {
@@ -1641,8 +1642,10 @@ void init_pop_source(struct _retrieve_src *source) {
 void free_pop_source(struct _retrieve_src *source) {
 	if(source->spec) {
 		init_pop_source(source);
-		free(source->spec);
-		source->spec = NULL;
+		if(source->spec != NULL) {
+			free(source->spec);
+			source->spec = NULL;
+		}
 	}
 
 	return;
