@@ -1,4 +1,4 @@
-/* $Id: smtp.cpp,v 1.26 2002/01/05 07:53:11 cfreeze Exp $ */
+/* $Id: smtp.cpp,v 1.28 2002/02/08 07:06:47 duncan_haldane Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -26,7 +26,6 @@
  ******************************************************************************/
 
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <cfgfile.h>
@@ -735,7 +734,11 @@ int smtp_message(struct _mail_msg *msg, FILE * m_out)
 		}
 
 		smtp_addr(msg->header->Cc, "Cc", m_out, charset);
-		smtp_addr(msg->header->Bcc, "Bcc", m_out, charset);
+		if (msg->header->Bcc) {
+		  if (putline("Bcc:", m_out) == -1)
+		    return -1;
+		}
+		  
 
 	}
 
