@@ -1,4 +1,4 @@
-/* $Id: addr_book.cpp,v 1.9 2002/01/05 07:53:11 cfreeze Exp $ */
+/* $Id: addr_book.cpp,v 1.12 2002/07/27 20:07:24 cfreeze Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
@@ -40,7 +40,6 @@
 
 #include <glib.h>
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <choose_folder.h>
@@ -1044,7 +1043,7 @@ void AB_Save_Call(FL_OBJECT * obj, long param) {
 void AB_Import_Book_Call(FL_OBJECT * obj, long param) {
 	int imp_pup;
 
-	imp_pup = fl_defpup(obj->form->window, "Import from%t|.mailrc|Pine");
+	imp_pup = fl_defpup(obj->form->window, "Import from%t|.mailrc|Pine|Text");
 
 	switch(fl_dopup(imp_pup)) {
 		case 1:
@@ -1054,6 +1053,9 @@ void AB_Import_Book_Call(FL_OBJECT * obj, long param) {
 		case 2:
 			pine_import_aliases(NULL);
 			break;
+		case 3:
+			text_import_aliases(NULL);
+			break;
 	}
 
 	fl_freepup(imp_pup);
@@ -1244,6 +1246,7 @@ void AB_Modify_Call(FL_OBJECT * obj, long param) {
 						free(entry->description);
 					entry->description = NULL;
 					discard_address(entry->addr->next_addr);
+					entry->addr->next_addr = NULL;
 				} else {
 					p = addr;
 					if(strlen(p) > 16) {
@@ -2443,3 +2446,92 @@ void AL_Lookup_Call(FL_OBJECT * obj, long data) {
 		fl_set_input(alias_obj->AL_InputPGP, buf);
 	}
 }
+
+void text_import_aliases(char *afile) {
+	FILE *afd;
+	int aerrs = 0;
+	char buf[255], *p, *p1, *comm;
+	struct _abook_entry *entry;
+	struct _mail_addr *addr;
+	bool bDone = false;
+	char descript[255];
+	int iNumAddress = 0;
+
+	display_msg(MSG_MSG, "Text Import", "The first line should be the alias, then each address on a separate line.");
+
+	if(!afile) {
+		fl_set_fselector_title("Select text list file");
+		if(!(afile = (char *) fl_show_file_selector("Text address book file",
+										   homedir, ".*",
+										   "list.txt"))) return;
+	}
+
+	if((afd = fopen(afile, "r")) == NULL) {
+		display_msg(MSG_WARN, "Text Import", "Can not open %s", afile);
+		return;
+	}
+
+	if(!fgets(descript, 255, afd)) {
+		display_msg(MSG_WARN, "Text Import", "Empty address book");
+		return;
+	}
+
+	if((entry = (struct _abook_entry *) malloc(sizeof(struct _abook_entry))) == NULL) {
+		display_msg(MSG_FATAL, "Text Import", "Malloc failed");
+		bDone = true;
+		return;
+	}
+
+	descript[254] = '\0';
+
+	strip_newline(descript);
+
+	entry->description = strdup(descript);
+	entry->addr =  NULL;
+	entry->type = ADDR_ALIAS;
+
+	display_msg(MSG_LOG, "Text Import", "Importing -> List Description / Alias: \"%s\"", descript);
+	while(!bDone) {
+
+		if(!fgets(buf, 255, afd)) {
+			bDone = true;
+			continue;
+		}
+
+		buf[254] = '\0';
+
+		strip_newline(buf);
+
+		addr = get_address(buf,0);
+
+		if(addr == NULL) {
+			aerrs++;
+			display_msg(MSG_LOG, "Text Import",
+						"invalid address entry in address book: %s", p);
+			continue;
+		}
+		display_msg(MSG_LOG, "Text Import", "Found %s (%s)", buf, addr->addr);
+
+		addr->next_addr = entry->addr;
+		entry->addr = addr;
+		iNumAddress++;
+	}
+
+	entry->next = book->entries; //tack onto back of address books
+	book->entries = entry; //set new head on address book list
+
+	fclose(afd);
+
+	if(aerrs)
+		display_msg(MSG_WARN, "Text Import",
+					"there were errors during import\ncheck log for more details");
+
+	display_msg(MSG_MSG, "Text Import", "Imported %i addresses", iNumAddress);
+	display_msg(MSG_LOG, "Text Import", "Imported %i addresses", iNumAddress);
+
+	changed = 1;
+	sort_book();
+	display_book();
+
+	return;
+}
