@@ -1,4 +1,4 @@
-/* $Id: inc.cpp,v 1.20 2002/01/05 07:53:12 cfreeze Exp $ */
+/* $Id: inc.cpp,v 1.22 2002/01/26 03:14:54 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
@@ -40,7 +40,6 @@
 
 #include <glib.h>
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <choose_folder.h>
@@ -143,7 +142,7 @@ void Inc_GPasswd_Call(FL_OBJECT * obj, long param) {
 #else
 	fl_show_alert("Encryption not supported",
 	    "This executable was not compiled with encryption support",
-	    "Please download the source and recompile with the\n--use-gpasswd option in configuring.",
+	    "Please download the source and recompile with the\n--enable-gpasswd option in configuring.",
 				  1);
 	fl_set_button(inc_obj->Inc_GPasswd, 0);
 #endif
