@@ -1,4 +1,4 @@
-/* $Id: pop_smtp.cpp,v 1.16 2002/01/05 07:53:12 cfreeze Exp $ */
+/* $Id: pop_smtp.cpp,v 1.19 2002/07/11 02:28:19 cfreeze Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
@@ -38,7 +38,6 @@
  ******************************************************************************/
 
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <choose_folder.h>
@@ -183,6 +182,9 @@ void pop_acc(struct _retrieve_src *source) {
 	ready = 1;
 	pop_acc_obj = create_form_acc_pop();
 
+	fl_set_input_maxchars(pop_acc_obj->Pop_User,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(pop_acc_obj->Pop_Password,POP_MAX_PASSWD_LEN);
+
 	fl_set_input(pop_acc_obj->Pop_Host, pop->hostname);
 	fl_set_input(pop_acc_obj->Pop_Port, pop->service);
 	fl_set_input(pop_acc_obj->Pop_User, pop->username);
@@ -289,6 +291,9 @@ void pop_account(struct _pop_src *pop) {
 
 	ready = 1;
 
+	fl_set_input_maxchars(pacc_obj->P_Username,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(pacc_obj->P_Password,POP_MAX_PASSWD_LEN);
+
 	fl_set_input(pacc_obj->P_Username, pop->username);
 	fl_set_input(pacc_obj->P_Password, pop->password);
 	fl_set_object_label(pacc_obj->P_Server, pop->hostname);
@@ -324,6 +329,9 @@ void nntp_account() {
 
 	ready = 1;
 
+	fl_set_input_maxchars(pacc_obj->P_Username,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(pacc_obj->P_Password,POP_MAX_USERNAME_LEN);
+
 	fl_set_input(pacc_obj->P_Username,
 				 Config.getCString("nntpuser", user_n));
 	fl_set_input(pacc_obj->P_Password,
@@ -351,6 +359,9 @@ void auth_smtp_account(char * hostname, char * username , char * password) {
 
 	ready = 1;
 
+	fl_set_input_maxchars(pacc_obj->P_Username,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(pacc_obj->P_Password,POP_MAX_USERNAME_LEN);
+
 	fl_set_input(pacc_obj->P_Username, username);
 	fl_set_input(pacc_obj->P_Password, password);
 	fl_set_object_label(pacc_obj->P_Server, hostname);
@@ -382,6 +393,10 @@ void auth_smtp_account(char * hostname, char * username , char * password) {
 void news_conf(int set_default, FD_config_news * form) {
 
 	nntp_obj = form;
+
+	fl_set_input_maxchars(nntp_obj->NNTP_Username,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(nntp_obj->NNTP_Password,POP_MAX_PASSWD_LEN);
+
 	fl_set_input(nntp_obj->NNTP_Host,
 				 Config.getCStringDefault("nntphost", "news", set_default));
 	fl_set_input(nntp_obj->NNTP_Port,
@@ -403,6 +418,10 @@ void news_conf(int set_default, FD_config_news * form) {
 
 void handle_news_input(FD_config_news * form) {
 	nntp_obj = form;
+
+	fl_set_input_maxchars(nntp_obj->NNTP_Username,POP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(nntp_obj->NNTP_Password,POP_MAX_PASSWD_LEN);
+
 	Config.set("nntphost", (char *) fl_get_input(nntp_obj->NNTP_Host));
 	Config.set("nntport", (char *) fl_get_input(nntp_obj->NNTP_Port));
 	Config.set("nntpuser", (char *) fl_get_input(nntp_obj->NNTP_Username));
@@ -541,6 +560,9 @@ void smtp_acc(struct _smtp_account *smtp) {
 	ready = 1;
 	smtp_acc_obj = create_form_acc_smtp();
 
+	fl_set_input_maxchars(smtp_acc_obj->SMTP_Acct_User,SMTP_MAX_USERNAME_LEN);
+	fl_set_input_maxchars(smtp_acc_obj->SMTP_Acct_Pwd,SMTP_MAX_PASSWD_LEN);
+
 	fl_set_input(smtp_acc_obj->SMTP_Acct_Host, smtp->hostname);
 	fl_set_input(smtp_acc_obj->SMTP_Acct_Port, smtp->service);
 	fl_set_input(smtp_acc_obj->SMTP_Acct_Src,  smtp->src_name);
@@ -620,7 +642,7 @@ void smtp_acc(struct _smtp_account *smtp) {
 
 
 void SMTP_Acct_Storepwd_Call(FL_OBJECT * obj, long param) {
-  if(fl_get_button(pop_acc_obj->Pop_Storpwd)
+  if(fl_get_button(smtp_acc_obj->SMTP_Acct_Storpwd)
 #ifdef USE_GPASSWD 
 	 && (Config.getInt("use_gpasswd", 0) == 0)
 #endif
