@@ -1,4 +1,4 @@
-/* $Id: rules.cpp,v 1.14 2002/01/05 07:53:12 cfreeze Exp $ */
+/* $Id: rules.cpp,v 1.16 2002/01/26 03:14:55 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
@@ -37,12 +37,8 @@
  *                                                                             *
  ******************************************************************************/
 
-#include <vector>
-#include <string>
-
 #include <glib.h>
 
-#include <config.h>
 #include <fmail.h>
 #include <umail.h>
 #include <choose_folder.h>
@@ -366,7 +362,7 @@ void Rule_Delete_Call(FL_OBJECT * obj, long param) {
 	r_modified = 0;
 	fl_delete_browser_line(rule_obj->Rule_List, k);
 	add_dead_rule(rules[i]);
-	rules.erase(&rules[i]);
+	rules.erase((vector<struct _xf_rule *>::iterator) &rules[i]);
 
 	changed = 1;
 
